Just tried new Kotlin/Native smallBinary option in Kotlin 2.2.20-Beta1.in project here (github.com/joreilly/Con...) and seeing over 20% reduction in size when building release version 🚀 btw remember to set following! kotlin.native.binary.smallBinary=true
Post
Build time improved quite a bit as well.....ran a few before/after builds and went on average (again for Confetti project) from 476s to 344s (this was for case when running archive build in Xcode)
0 reposts4 likes
A few comments/concerns understandably about "it might affect runtime performance in some cases."....fwiw I've published version of Confetti that uses this to App Store and haven't noticed any difference (apps.apple.com/us/app/confe...)
apps.apple.comConfettiApp for browsing information for a range of conferences. Allows viewing session and speaker details.